@@ -8,7 +8,7 @@ Perl::Dist::VanillaWiX - Minimal distribution of Perl, useful only for testing.
 
 =head1 VERSION
 
-This document describes Perl::Dist::VanillaWiX version 1.102.
+This document describes Perl::Dist::VanillaWiX version 1.200.
 
 =head1 DESCRIPTION
 
@@ -39,7 +39,7 @@ use strict;
 use warnings;
 use parent qw(Perl::Dist::WiX);
 
-our $VERSION = '1.102';
+our $VERSION = '1.200';
 $VERSION =~ s/_//ms;
 
 #####################################################################
@@ -49,7 +49,7 @@ $VERSION =~ s/_//ms;
 
 =head2 new
 
-See L<Perl::Dist::WiX-E<gt>new|Perl::Dist::WiX/new>.
+See L<< Perl::Dist::WiX->new()|Perl::Dist::WiX/new >>.
 
 =cut
 
@@ -58,7 +58,7 @@ sub new {
 	my %args;
 
 	# Check for the correct version of Perl::Dist::WiX.
-	Perl::Dist::WiX->VERSION(1.102);
+	Perl::Dist::WiX->VERSION(1.200);
 
 	if ( @_ == 1 && 'HASH' eq ref $_[0] ) {
 		%args = %{ $_[0] };
@@ -66,7 +66,8 @@ sub new {
 		%args = (@_);
 	} else {
 		PDWiX->throw(
-			'Parameters incorrect (not a hashref or hash) for ::Asset::*');
+'Parameters incorrect (not a hashref or hash) for Perl::Dist::VanillaWiX->new'
+		);
 	}
 
 	%args = (
@@ -75,7 +76,7 @@ sub new {
 		app_id            => 'vanilla-perl',
 		app_name          => 'Vanilla Perl',
 		app_publisher     => 'Vanilla Perl Project',
-		image_dir         => 'C:\WiXTest',
+		image_dir         => 'C:\vanilla',
 		build_number      => 20,
 		%args,
 	);
