@@ -1,5 +1,50 @@
 package Perl::Dist::WiX::Asset::PAR;
 
+=pod
+
+=head1 NAME
+
+Perl::Dist::WiX::Asset::PAR - "Binary .par package" asset for a Win32 Perl
+
+=head1 VERSION
+
+This document describes Perl::Dist::WiX::Asset::PAR version 1.200.
+
+=head1 SYNOPSIS
+
+  my $binary = Perl::Dist::Asset::PAR->new(
+    parent => $dist, # A Perl::Dist::WiX object.
+    name   => 'dmake',
+    url    => 'http://parrepository.de/Perl-Dist-PrepackagedPAR-libexpat-2.0.1-MSWin32-x86-multi-thread-anyversion.par',
+  );
+  
+  # Or usually more like this:
+  $perl_dist_wix_obj->install_par(
+    name => 'Perl-Dist-PrepackagedPAR-libexpat',
+    url  => 'http://parrepository.de/Perl-Dist-PrepackagedPAR-libexpat-2.0.1-MSWin32-x86-multi-thread-anyversion.par',
+  );
+
+=head1 DESCRIPTION
+
+B<Perl::Dist::WiX::Asset::PAR> is a data class that provides encapsulation
+and error checking for a "binary .par package" to be installed in a
+L<Perl::Dist::WiX|Perl::Dist::WiX>-based Perl distribution.
+
+It is normally created by the L<install_par|Perl::Dist::WiX::Installation/install_par> 
+method of C<Perl::Dist::WiX> (and other things that call it). 
+
+The specification of the location to retrieve the package is done via
+the standard mechanism implemented in L<Perl::Dist::WiX::Asset|Perl::Dist::WiX::Asset>.
+
+The C<install_to> argument of the 
+L<Perl::Dist::WiX::Asset::Library|Perl::Dist::WiX::Asset::Library> 
+asset is not supported by the PAR asset.
+
+See L</PAR FILE FORMAT EXTENSIONS> below for details on how non-Perl binaries
+are installed.
+
+=cut
+
 use 5.008001;
 use Moose;
 use MooseX::Types::Moose qw( Str );
@@ -9,11 +54,38 @@ require SelectSaver;
 require PAR::Dist;
 require IO::String;
 
-our $VERSION = '1.102';
+our $VERSION = '1.200';
 $VERSION =~ s/_//ms;
 
 with 'Perl::Dist::WiX::Role::Asset';
 
+=head1 METHODS
+
+This class is a L<Perl::Dist::WiX::Role::Asset|Perl::Dist::WiX::Role::Asset> 
+and shares its API.
+
+=pod
+
+=head2 new
+
+The C<new> constructor takes a series of parameters, validates them
+and returns a new B<Perl::Dist::WiX::Asset::PAR> object.
+
+The C<new> constructor will throw an exception (dies) if an invalid 
+parameter is provided.
+
+It inherits all the parameters described in the 
+L<Perl::Dist::WiX::Asset/new|Perl::Dist::WiX::Asset-E<gt>new()> 
+method documentation, and adds an additional parameter.
+
+=head3 name
+
+The required C<name> parameter is the name of the package for the purposes 
+of identification in output. A sensible default would be the name of
+the primary Perl module in the package.
+
+=cut
+
 has name => (
 	is       => 'ro',
 	isa      => Str,
@@ -21,6 +93,12 @@ has name => (
 	required => 1,
 );
 
+=head2 install
+
+The C<install> method retrieves the specified .par file and installs it71.
+
+=cut
+
 sub install {
 	my $self = shift;
 
@@ -123,79 +201,12 @@ __PACKAGE__->meta->make_immutable;
 
 __END__
 
-=pod
-
-=head1 NAME
-
-Perl::Dist::WiX::Asset::PAR - "Binary .par package" asset for a Win32 Perl
-
-=head1 SYNOPSIS
-
-  my $binary = Perl::Dist::Asset::PAR->new(
-      name       => 'dmake',
-  );
-  
-  # Or usually more like this:
-  $perl_dist_wix_obj->install_par(
-    name => 'Perl-Dist-PrepackagedPAR-libexpat',
-    url  => 'http://parrepository.de/Perl-Dist-PrepackagedPAR-libexpat-2.0.1-MSWin32-x86-multi-thread-anyversion.par',
-  );
-
-=head1 DESCRIPTION
-
-B<Perl::Dist::WiX::Asset::PAR> is a data class that provides encapsulation
-and error checking for a "binary .par package" to be installed in a
-L<Perl::Dist::WiX|Perl::Dist::WiX>-based Perl distribution.
-
-It is normally created by the L<install_par|Perl::Dist::WiX::Installation/install_par> 
-method of C<Perl::Dist::WiX> (and other things that call it). 
-
-The specification of the location to retrieve the package is done via
-the standard mechanism implemented in L<Perl::Dist::WiX::Asset|Perl::Dist::WiX::Asset>.
-
-The C<install_to> argument of the 
-L<Perl::Dist::WiX::Asset::Library|Perl::Dist::WiX::Asset::Library> 
-asset is not supported by the PAR asset.
-
-See L<PAR FILE FORMAT EXTENSIONS> below for details on how non-Perl binaries
-are installed.
-
-=head1 METHODS
-
-This class is a L<Perl::Dist::WiX::Role::Asset|Perl::Dist::WiX::Role::Asset> 
-and shares its API.
-
-=head2 new
-
-The C<new> constructor takes a series of parameters, validates them
-and returns a new B<Perl::Dist::Asset::PAR> object.
-
-It inherits all the parameters described in the C<Perl::Dist::WiX::Asset> 
-C<new> method documentation, and adds an additional parameter.
-
-=over 4
-
-=item name
-
-The required C<name> param is the logical name of the package for the 
-purposes of identification. A sensible default would be the name of
-the primary Perl module in the package.
-
-=back
-
-The C<new> constructor returns a B<Perl::Dist::WiX::Asset::PAR> object,
-or throws an exception (dies) if an invalid param is provided.
-
-=head2 install
-
-The C<install> method installs the retrieved .par file.
-
 =head1 PAR FILE FORMAT EXTENSIONS
 
 This concerns packagers of .par binaries only.
  
 A .par usually mostly contains the blib/ directory after making a Perl module.
-For use with Perl::Dist::Asset::PAR, there are currently three more subdirectories
+For use with Perl::Dist::Asset::PAR, there are currently four more subdirectories
 which will be installed:
 
  blib/c/lib     => goes into the c/lib library directory for non-Perl extensions
@@ -217,7 +228,8 @@ Curtis Jewell E<lt>csjewell@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<Perl::Dist::WiX>, L<Perl::Dist::WiX::Asset>
+L<Perl::Dist::WiX|Perl::Dist::WiX>, 
+L<Perl::Dist::WiX::Role::Asset|Perl::Dist::WiX::Role::Asset>
 
 =head1 COPYRIGHT AND LICENSE
 
