@@ -8,7 +8,7 @@ Perl::Dist::WiX::ReleaseNotes - Creates accessory files.
 
 =head1 VERSION
 
-This document describes Perl::Dist::WiX::ReleaseNotes version 1.102.
+This document describes Perl::Dist::WiX::ReleaseNotes version 1.200.
 
 =head1 DESCRIPTION
 
@@ -18,7 +18,7 @@ make the distributions.txt and the release notes files.
 =head1 SYNOPSIS
 
 	# This module is not to be used independently.
-	# It provides methods to a Perl::Dist::WiX object.
+	# It provides methods to be called on a Perl::Dist::WiX object.
 
 =head1 INTERFACE
 
@@ -29,12 +29,13 @@ use Moose;
 use English qw( -no_match_vars );
 use File::Spec::Functions qw( catfile );
 require IO::File;
-require Template;
 require File::List::Object;
 
-our $VERSION = '1.102';
+our $VERSION = '1.200';
 $VERSION =~ s/_//ms;
 
+
+
 =head2 release_notes_filename
 
 The C<release_notes_filename> method returns the name of the release 
@@ -42,12 +43,15 @@ notes framework file.
 
 =cut
 
+
+
 sub release_notes_filename {
 	my $self = shift;
 	my $filename =
 	    $self->perl_version_human() . q{.}
 	  . $self->build_number()
-	  . ( $self->beta_number() ? '.beta' : q{} ) . '.html';
+	  . ( $self->beta_number() ? '.beta.' . $self->beta_number() : q{} )
+	  . '.html';
 
 	return $filename;
 }
@@ -61,6 +65,8 @@ release notes to upload to a web site.
 
 =cut
 
+
+
 sub create_release_notes {
 	my $self = shift;
 	my $dist_list;
@@ -83,14 +89,7 @@ sub create_release_notes {
 		dist_date => $date,
 	};
 
-	my $tt = Template->new(
-		INCLUDE_PATH => [ $self->dist_dir(), $self->wix_dist_dir(), ],
-		ABSOLUTE     => 1,
-	  )
-	  || PDWiX::Caught->throw(
-		message => 'Template error',
-		info    => Template->error(),
-	  );
+	my $tt = $self->patch_template();
 
 	$tt->process( 'release_notes.html.tt', $vars, \$dist_txt )
 	  || PDWiX::Caught->throw(
@@ -118,12 +117,8 @@ sub create_release_notes {
 } ## end sub create_release_notes
 
 
-#####################################################################
-# DISTRIBUTIONS.txt
-
-# NOTE: "The object that called it" is supposed to be a Perl::Dist::WiX
-# object.
 
+# Private routine used to add to the distributions list.
 sub _add_to_distributions_installed {
 	my $self = shift;
 	my $dist = shift;
@@ -136,14 +131,36 @@ sub _add_to_distributions_installed {
 
 =head2 create_distribution_list
 
-The C<create_distribution_list> method creates the DISTRIBUTIONS.txt file
-that contains the list of distributions that are installed, and adds it to
-the .msi.
+The C<create_distribution_list> method creates the DISTRIBUTIONS.txt file 
+for a L<Perl::Dist::WiX|Perl::Dist::WiX>-based distribution.
 
 =cut
 
+
+
 sub create_distribution_list {
 	my $self = shift;
+
+	return $self->create_distribution_list_file('DISTRIBUTIONS.txt');
+}
+
+
+
+=head2 create_distribution_list_file
+
+    $self->create_distribution_list_file('DISTRIBUTIONS.txt');
+
+The C<create_distribution_list_file> method creates a distribution list file
+(like DISTRIBUTIONS.txt) that contains the list of distributions that are 
+installed, and adds it to the .msi.
+
+=cut
+
+
+
+sub create_distribution_list_file {
+	my $self           = shift;
+	my $dist_file_name = shift;
 	my $dist_list;
 	my ( $name, $ver );
 
@@ -158,22 +175,15 @@ sub create_distribution_list {
 		dist_list => $dist_list
 	};
 
-	my $tt = Template->new(
-		INCLUDE_PATH => [ $self->dist_dir(), $self->wix_dist_dir(), ],
-		ABSOLUTE     => 1,
-	  )
-	  || PDWiX::Caught->throw(
-		message => 'Template error',
-		info    => Template->error(),
-	  );
+	my $tt = $self->patch_template();
 
-	$tt->process( 'DISTRIBUTIONS.txt.tt', $vars, \$dist_txt )
+	$tt->process( "${dist_file_name}.tt", $vars, \$dist_txt )
 	  || PDWiX::Caught->throw(
 		message => 'Template error',
 		info    => $tt->error(),
 	  );
 
-	my $dist_file = catfile( $self->image_dir, q{DISTRIBUTIONS.txt} );
+	my $dist_file = catfile( $self->image_dir, $dist_file_name );
 	my $fh = IO::File->new( $dist_file, 'w' );
 
 	$self->trace_line( 2, "Creating distribution list at $dist_file\n" );
@@ -191,7 +201,7 @@ sub create_distribution_list {
 	$self->insert_fragment( 'perl_dist_list', $dist_file_list );
 
 	return 1;
-} ## end sub create_distribution_list
+} ## end sub create_distribution_list_file
 
 1;
 
@@ -221,7 +231,7 @@ Curtis Jewell E<lt>csjewell@cpan.orgE<gt>
 
 =head1 SEE ALSO
 
-L<Perl::Dist|Perl::Dist>, L<Perl::Dist::WiX|Perl::Dist::WiX>, 
+L<Perl::Dist::WiX|Perl::Dist::WiX>, 
 L<http://ali.as/>, L<http://csjewell.comyr.com/perl/>
 
 =head1 COPYRIGHT AND LICENSE
